@@ -117,9 +117,13 @@ def get_vis_font(vis_font_path):
             vis_font_path = temp_path+'.ttf'
     return vis_font_path
 
-def str2providers(str):
+
+def str2providers(str, logger):
     available_providers = ort.get_available_providers()
 
+    if str.lower() == 'auto':
+        return available_providers
+
     providers_dict = {
         provider.lower(): provider 
         for provider in available_providers
@@ -137,18 +141,17 @@ def str2providers(str):
     ]
 
     if len(select_providers) == 0:
+        logger.error('No available providers: {}'.format(str.split(',')))
+        logger.error('Automatically sets the available providers as the default providers!'.format(str.split(',')))
         select_providers = available_providers
-
+        
     return select_providers
 
 def init_args():
     parser = argparse.ArgumentParser()
 
-    # params for config
-    parser.add_argument("--show_log", type=bool, default=True)
-
     # params for onnx engine
-    parser.add_argument("--providers", type=str, default='')
+    parser.add_argument("--providers", type=str, default='auto')
     
     # params for text detector
     parser.add_argument("--det_algorithm", type=str, default='DB')
@@ -160,7 +163,6 @@ def init_args():
     parser.add_argument("--det_db_thresh", type=float, default=0.3)
     parser.add_argument("--det_db_box_thresh", type=float, default=0.6)
     parser.add_argument("--det_db_unclip_ratio", type=float, default=1.5)
-    parser.add_argument("--max_batch_size", type=int, default=8)
     parser.add_argument("--use_dilation", type=bool, default=False)
     parser.add_argument("--det_db_score_mode", type=str, default="fast")
 
@@ -187,7 +189,6 @@ def init_args():
     parser.add_argument("--drop_score", type=float, default=0.5)
 
     # params for text classifier
-    parser.add_argument("--use_angle_cls", type=bool, default=True)
     parser.add_argument("--cls_model_dir", type=str, default='ch_ppocr_mobile_v2.0_cls')
     parser.add_argument("--cls_image_shape", type=str, default="3, 48, 192")
     parser.add_argument("--label_list", type=list, default=['0', '180'])
@@ -197,6 +198,9 @@ def init_args():
     # multi-process
     parser.add_argument("--total_process_num", type=int, default=1)
 
+    # params for config
+    parser.add_argument("--show_log", type=bool, default=True)
+
     return parser
 
 
@@ -237,7 +241,7 @@ def create_session(args, mode, logger):
         sys.exit(0)
 
     sess_options = ort.SessionOptions()
-    providers = str2providers(args.providers)
+    providers = str2providers(args.providers, logger)
     logger.info('Using providers: {}'.format([provider[:-17] for provider in providers]))
     if 'DmlExecutionProvider' in providers:
         logger.info('Disable mem_pattern because using the Dml Provider.')
@@ -252,23 +256,6 @@ def create_session(args, mode, logger):
     return session, input_names, output_names
 
 
-
-def draw_e2e_res(dt_boxes, strs, img_path):
-    src_im = cv2.imread(img_path)
-    for box, str in zip(dt_boxes, strs):
-        box = box.astype(np.int32).reshape((-1, 1, 2))
-        cv2.polylines(src_im, [box], True, color=(255, 255, 0), thickness=2)
-        cv2.putText(
-            src_im,
-            str,
-            org=(int(box[0, 0, 0]), int(box[0, 0, 1])),
-            fontFace=cv2.FONT_HERSHEY_COMPLEX,
-            fontScale=0.7,
-            color=(0, 255, 0),
-            thickness=1)
-    return src_im
-
-
 def draw_text_det_res(dt_boxes, img_path):
     src_im = cv2.imread(img_path)
     for box in dt_boxes:
